/*
 * SonarLint for IntelliJ IDEA
 * Copyright (C) 2015-2021 SonarSource
 * sonarlint@sonarsource.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonarlint.intellij.issue.vulnerabilities

import com.intellij.openapi.application.runInEdt
import com.intellij.openapi.fileEditor.FileEditorManager
import com.intellij.openapi.fileEditor.FileEditorManagerListener
import com.intellij.openapi.project.Project
import com.intellij.openapi.vfs.VirtualFile
import org.sonarlint.intellij.common.util.SonarLintUtils.getService
import org.sonarlint.intellij.config.global.SonarLintGlobalSettings
import org.sonarlint.intellij.messages.GlobalConfigurationListener
import org.sonarlint.intellij.messages.ProjectConfigurationListener
import org.sonarlint.intellij.tasks.BindingStorageUpdateTask

class TaintVulnerabilitiesRefreshTrigger(private val project: Project) {

  fun subscribeToTriggeringEvents() {
    val busConnection = project.messageBus.connect()
    with(busConnection) {
      subscribe(FileEditorManagerListener.FILE_EDITOR_MANAGER, object : FileEditorManagerListener {
        override fun fileOpened(source: FileEditorManager, file: VirtualFile) {
          triggerRefresh()
        }

        override fun fileClosed(source: FileEditorManager, file: VirtualFile) {
          triggerRefresh()
        }
      })
      subscribe(ProjectConfigurationListener.TOPIC, ProjectConfigurationListener { triggerRefresh() })
      subscribe(GlobalConfigurationListener.TOPIC, object : GlobalConfigurationListener.Adapter() {
        override fun applied(settings: SonarLintGlobalSettings) {
          triggerRefresh()
        }
      })
      subscribe(BindingStorageUpdateTask.Listener.TOPIC, BindingStorageUpdateTask.Listener { runInEdt { triggerRefresh() } })
    }

    triggerRefresh()
  }

  private fun triggerRefresh() {
    getService(project, TaintVulnerabilitiesPresenter::class.java).presentTaintVulnerabilitiesForOpenFiles()
  }
}
